@@ -24,20 +24,18 @@
 
 class LocalGame : public Game
 {
-    Q_OBJECT
 public:
     explicit LocalGame(QObject *parent = 0);
 
-    virtual void start();
-    virtual void stop();
-signals:
+    void start() override;
+    void stop() override;
 
-public slots:
+public:
     void addPlayer(Player *player);
-
     void playerIsDone();
+
 protected:
-    virtual void buildMachine();
+    void buildMachine() override;
 };
 
 #endif // LOCALGAME_H
